#ifndef IO_EXPANDER_H
#define	IO_EXPANDER_H

/*******************************************************************************************************************
 * I2C Peripherial Select - enable one set of these defines in the application header file
 * for the module used for the I/O Expander.
 * These functions depend on inclusion of MCC Generated code i2c1.h and i2c1.c or i2c2.h and i2c2.c
*******************************************************************************************************************/
#ifdef LCD_IOEXPANDER1
// Enabled for I2C1 (MSSP1))
#define I2C_MasterWrite I2C1_MasterWrite
#define I2C_MasterRead I2C1_MasterRead
#define I2C_MESSAGE_STATUS I2C1_MESSAGE_STATUS
#define I2C_MESSAGE_COMPLETE I2C1_MESSAGE_COMPLETE
#define I2C_MESSAGE_FAIL I2C1_MESSAGE_FAIL
#define I2C_MESSAGE_PENDING I2C1_MESSAGE_PENDING
#endif

#ifdef LCD_IOEXPANDER2
// Enabled for I2C2 (MSSP2))
#define I2C_MasterWrite I2C2_MasterWrite
#define I2C_MasterRead I2C2_MasterRead
#define I2C_MESSAGE_STATUS I2C2_MESSAGE_STATUS
#define I2C_MESSAGE_COMPLETE I2C2_MESSAGE_COMPLETE
#define I2C_MESSAGE_FAIL I2C1_MESSAGE_FAIL
#define I2C1_MESSAGE_PENDING I2C1_MESSAGE_PENDING
#endif

/*******************************************************************************************************************
 * Define a max number of times (less than 255) to try an I2C Read or I2C Write to a device
*******************************************************************************************************************/
#define SLAVE_I2C_RETRY_MAX 1

/*******************************************************************************************************************
 * User APIs
*******************************************************************************************************************/
/*******************************************************************************************************************
 * Function: void IO_ExpanderInitialize(uint8_t data, uint8_t adr);
 * Overview: Initializes the I/O Expander
 * PreCondition: None
*******************************************************************************************************************/
void IO_ExpanderInitialize(uint8_t data, uint8_t adr);

/*******************************************************************************************************************
 * Function: void IO_ExpanderWrite(uint8_t data);
 * Overview: Write Data to the I/O Expander using I2C
 * PreCondition: None
*******************************************************************************************************************/
void IO_ExpanderWrite(uint8_t data);

/*******************************************************************************************************************
 * Function: uint8_t IO_ExpanderRead(uint8_t rs);
 * Overview: Read Data from the I/O Expander using I2C
 * PreCondition: None
*******************************************************************************************************************/
uint8_t IO_ExpanderRead(uint8_t rs);


void IO_ExpanderWaitBF(void);

#endif	/* IO_EXPANDER_H */
/*************** End of File **************************************************************************************/